pub enum Argument<Id, Fd> {
Int(i32),
Uint(u32),
Fixed(i32),
Str(Option<Box<CString>>),
Object(Id),
NewId(Id),
Array(Box<Vec<u8>>),
Fd(Fd),
}Expand description
Enum of possible argument of the protocol
Variants
Int(i32)
An integer argument. Represented by a i32.
Uint(u32)
An unsigned integer argument. Represented by a u32.
Fixed(i32)
A signed fixed point number with 1/256 precision
Str(Option<Box<CString>>)
CString
The value is boxed to reduce the stack size of Argument. The performance
impact is negligible as string arguments are pretty rare in the protocol.
Object(Id)
Id of a wayland object
NewId(Id)
Id of a newly created wayland object
Array(Box<Vec<u8>>)
Vec<u8>
The value is boxed to reduce the stack size of Argument. The performance
impact is negligible as array arguments are pretty rare in the protocol.
Fd(Fd)
A file descriptor argument. Represented by a RawFd.
Implementations